﻿/**
 * Copyright 2009 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Pena <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common;
using NUnit.Framework;

namespace Canonical.UbuntuOne.ProcessDispatcher.Tests
{
    [TestFixture]
    public class ConvertFixture
    {

        #region Tests

        [Test]
        public void ConvertToAccountDataTest()
        {
            // TODO: Wait until accunt data is correctly defined
            Assert.Ignore("Wait until accunt data is correctly defined");
        }

        [Test]
        public void ConvertToAccountProtoTest()
        {
            // TODO: Wait until account data is correctly defined
            Assert.Ignore("Wait until accunt data is correctly defined");
        }

        [Test]
        public void ConvertToDownloadDataTest()
        {
            var proto = new DownloadProto
            {
                NodeId = "NodeId",
                NumberOfBytesRead = 300,
                Path = "/path/to/test",
                VolumeId = "VolumeId"
            };
            var data = Convert.ToDownloadData(proto);
            Assert.AreEqual(proto.NodeId, data.NodeId);
            Assert.AreEqual(proto.NumberOfBytesRead, data.NumberOfBytesRead);
            Assert.AreEqual(proto.Path, data.Path);
            Assert.AreEqual(proto.VolumeId, data.VolumeId);
        }

        [Test]
        public void ConvertToDownloadProtoTest()
        {
            var data = new DownloadData
            {
                NodeId = "NodeId",
                NumberOfBytesRead = 300,
                Path = "/path/to/test",
                VolumeId = "VolumeId"
            };
            var proto = Convert.ToDownloadProto(data);
            Assert.AreEqual(data.NodeId, proto.NodeId);
            Assert.AreEqual(data.NumberOfBytesRead, proto.NumberOfBytesRead);
            Assert.AreEqual(data.Path, proto.Path);
            Assert.AreEqual(data.VolumeId, proto.VolumeId);
        }

        [Test]
        public void ConvertToQueueItemDataTest()
        {
            var proto = new QueueItemProto
            {
                NodeId = "NodeID",
                Operation = "Update",
                Path = "/path/to/test",
                VolumeId = "VolumeId"
            };
            var data = Convert.ToQueueItemData(proto);
            Assert.AreEqual(proto.NodeId, data.NodeId);
            Assert.AreEqual(proto.Operation, data.Operation);
            Assert.AreEqual(proto.Path, data.Path);
            Assert.AreEqual(proto.VolumeId, data.VolumeId);
        }

        [Test]
        public void ConvertToQueueItemProtoTest()
        {
            var data = new QueueItemData
            {
                NodeId = "NodeId",
                Operation = "Update",
                Path = "/path/to/test",
                VolumeId = "VolumnId"
            };
            var proto = Convert.ToQueueItemProto(data);
            Assert.AreEqual(data.NodeId, proto.NodeId);
            Assert.AreEqual(data.Operation, proto.Operation);
            Assert.AreEqual(data.Path, proto.Path);
            Assert.AreEqual(data.VolumeId, proto.VolumeId);
        }

        [Test]
        public void ConvertToShareDataTest()
        {
            var proto = new ShareProto
            {
                AccessLevel = AccessLevel.VIEW,
                FreeBytes = 34,
                IsAccepted = true,
                Name = "MyDocs",
                NodeId = "NodeId",
                OtherUserName = "mandel",
                OtherVisisbleName = "Manuel de la Pena",
                Path = "/path/to/test",
                VolumeId = "VolumeId"
            };
            var data = Convert.ToShareData(proto);
            Assert.AreEqual(proto.AccessLevel, data.AccessLevel);
            Assert.AreEqual(proto.FreeBytes, data.FreeBytes);
            Assert.AreEqual(proto.IsAccepted, data.IsAccepted);
            Assert.AreEqual(proto.Name, data.Name);
            Assert.AreEqual(proto.NodeId, data.NodeId);
            Assert.AreEqual(proto.OtherUserName, data.OtherUserName);
            Assert.AreEqual(proto.OtherVisisbleName, data.OtherVisisbleName);
            Assert.AreEqual(proto.Path, data.Path);
            Assert.AreEqual(proto.VolumeId, data.VolumeId);
        }

        [Test]
        public void ConvertToShareProtoTest()
        {
            var data = new ShareData
            {
                AccessLevel = AccessLevel.VIEW,
                FreeBytes = 23,
                IsAccepted = true,
                Name = "MyDocs",
                NodeId = "NodeId",
                OtherUserName = "mandel",
                OtherVisisbleName = "Manuel de la Pena",
                Path = "/path/to/test",
                VolumeId = "VolumeId"
            };
            var proto = Convert.ToShareProto(data);
            Assert.AreEqual(data.AccessLevel, proto.AccessLevel);
            Assert.AreEqual(data.FreeBytes, proto.FreeBytes);
            Assert.AreEqual(data.IsAccepted, proto.IsAccepted);
            Assert.AreEqual(data.Name, proto.Name);
            Assert.AreEqual(data.NodeId, proto.NodeId);
            Assert.AreEqual(data.OtherUserName, proto.OtherUserName);
            Assert.AreEqual(data.OtherVisisbleName, proto.OtherVisisbleName);
            Assert.AreEqual(data.Path, proto.Path);
            Assert.AreEqual(data.VolumeId, proto.VolumeId);
        }

        [Test]
        public void ConvertToShareResponseDataTest()
        {
            // TODO: wait until share reponse is fully defined.
            Assert.Ignore("wait until share reponse is fully defined.");
        }

        [Test]
        public void ConvertToShareResponseProtoTest()
        {
            // TODO: wait until share reponse is fully defined.
            Assert.Ignore("wait until share reponse is fully defined.");
        }

        [Test]
        public void ConvertToStateDataTest()
        {
            var proto = new StateProto
            {
                Description = "Description",
                IsConnected = true,
                IsError = false,
                IsOnline = true,
                Name = "State"
            };
            var data = Convert.ToStateData(proto);
            Assert.AreEqual(proto.Description, data.Description);
            Assert.AreEqual(proto.IsConnected, data.IsConnected);
            Assert.AreEqual(proto.IsError, data.IsError);
            Assert.AreEqual(proto.IsOnline, data.IsOnline);
            Assert.AreEqual(proto.Name, data.Name);
        }

        [Test]
        public void ConvertToStateProtoTest()
        {
            var data = new StateData
            {
                Description = "Description",
                IsConnected = true,
                IsError = false,
                IsOnline = true,
                Name = "State"
            };
            var proto = Convert.ToStateProto(data);
            Assert.AreEqual(data.Description, proto.Description);
            Assert.AreEqual(data.IsConnected, proto.IsConnected);
            Assert.AreEqual(data.IsError, proto.IsError);
            Assert.AreEqual(data.IsOnline, proto.IsOnline);
            Assert.AreEqual(data.Name, proto.Name);
        }

        [Test]
        public void ConvertToThrottlingDataTest()
        {
            var proto = new ThrottlingProto
            {
                Download = 4,
                Upload = 7
            };
            var data = Convert.ToThrottlingData(proto);
            Assert.AreEqual(proto.Download, data.Download);
            Assert.AreEqual(proto.Upload, data.Upload);
        }

        [Test]
        public void ConvertToThrottlingProtoTest()
        {
            var data = new ThrottlingData
            {
                Download = 4,
                Upload = 7
            };
            var proto = Convert.ToThrottlingProto(data);
            Assert.AreEqual(data.Download, proto.Download);
            Assert.AreEqual(data.Upload, proto.Upload);
        }

        [Test]
        public void ConvertToUdfDataTest()
        {
            var proto = new UdfProto
            {
                IsSubscribed = true,
                NodeId = "NodeId",
                Path = "/path/to/test",
                SuggestedPath = "/suggested/path",
                VolumeId = "VolumeId"
            };
            var data = Convert.ToUdfData(proto);
            Assert.AreEqual(proto.IsSubscribed, data.IsSubscribed);
            Assert.AreEqual(proto.NodeId, data.NodeId);
            Assert.AreEqual(proto.Path, data.Path);
            Assert.AreEqual(proto.SuggestedPath, data.SuggestedPath);
            Assert.AreEqual(proto.VolumeId, data.VolumeId);
        }

        [Test]
        public void ConvertToUdfProtoTest()
        {
            var data = new UdfData
            {
                IsSubscribed = true,
                NodeId = "NodeId",
                Path = "/path/to/test",
                SuggestedPath = "/suggested/path",
                VolumeId = "VolumeId"
            };
            var proto = Convert.ToUdfProto(data);
            Assert.AreEqual(data.IsSubscribed, proto.IsSubscribed);
            Assert.AreEqual(data.NodeId, proto.NodeId);
            Assert.AreEqual(data.Path, proto.Path);
            Assert.AreEqual(data.SuggestedPath, proto.SuggestedPath);
            Assert.AreEqual(data.VolumeId, proto.VolumeId);
        }

        [Test]
        public void ConvertToUploadDataTest()
        {
            var proto = new UploadProto
            {
                NodeId = "NodeId",
                NumberOfBytesWritten = 34,
                Path = "/path/to/test",
                VolumeId = "VolumeId"
            };
            var data = Convert.ToUploadData(proto);
            Assert.AreEqual(proto.NodeId, data.NodeId);
            Assert.AreEqual(proto.NumberOfBytesWritten, data.NumberOfBytesWritten);
            Assert.AreEqual(proto.Path, data.Path);
            Assert.AreEqual(proto.VolumeId, data.VolumeId);
        }

        [Test]
        public void ConvertToUploadProtoTest()
        {
            var data = new UploadData
            {
                NodeId = "NodeId",
                NumberOfBytesWritten = 34,
                Path = "/path/to/test",
                VolumeId = "VolumeId"
            };
            var proto = Convert.ToUploadProto(data);
            Assert.AreEqual(data.NodeId, proto.NodeId);
            Assert.AreEqual(data.NumberOfBytesWritten, proto.NumberOfBytesWritten);
            Assert.AreEqual(data.Path, proto.Path);
            Assert.AreEqual(data.VolumeId, proto.VolumeId);
        }

        #endregion

    }
}
