﻿/**
 * Copyright 2009 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Pena <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common;

namespace Canonical.UbuntuOne.ProcessDispatcher
{
    /// <summary>
    /// Helper class that provides a number of helper method to convert between proto objects and data object.
    /// </summary>
    internal static class Convert
    {
        // All the following trasformation might look stupid, but there is a reason for them. We 
        // want to make a clear difference between the data contracts that the .Net clients will used and
        // the proto contracts and internal structures used to communicate between the python processes and 
        // the .Net UbuntuOne service this should give use a more stable API for the clients

        /// <summary>
        /// Ensures that the protobuf used to communicate with the python process is correctly transformed
        /// to a data contract that can be consumed by the .Net clients.
        /// </summary>
        /// <param name="proto">The protobuf used to communicate with python.</param>
        /// <returns>An data contract that can be consummed by the .Net clients.</returns>
        internal static AccountData ToAccountData(AccountProto proto)
        {
            //TODO: Finish account data definition
            return new AccountData();
        }

        /// <summary>
        /// Ensures that the data contract that is used to communicate with the Net clients is correctly
        /// transformed to a protobuf that can be used to communicate with the python process.
        /// </summary>
        /// <param name="data">The data contract that is used by the .Net client.</param>
        /// <returns>A protobuf that can be used to communicate with the python process.</returns>
        internal static AccountProto ToAccountProto(AccountData data)
        {
            // TODO: finish account proto definition
            return new AccountProto();
        }

        /// <summary>
        /// Ensures that the protobuf that is used to communicate with the python process is converted to 
        /// a data contract that can be consummed by .Net langauges.
        /// </summary>
        /// <param name="proto">The protobuffer to be converted.</param>
        /// <returns>A data contract that can be consummed by the .Net languages.</returns>
        internal static DownloadData ToDownloadData(DownloadProto proto)
        {
            return new DownloadData
            {
                NodeId = proto.NodeId,
                NumberOfBytesRead = proto.NumberOfBytesRead,
                Path = proto.Path,
                VolumeId = proto.VolumeId
            };
        }

        /// <summary>
        /// Ensures that the data contract that is used with the .Net languages is converted to a protobuffer
        /// that can be used to communicate with the python process.
        /// </summary>
        /// <param name="data">The .Net contract data to be transformet.</param>
        /// <returns>The protobuffer to be used to comumunicate with the python process.</returns>
        internal static DownloadProto ToDownloadProto(DownloadData data)
        {
            return new DownloadProto
            {
                NodeId = data.NodeId,
                NumberOfBytesRead = data.NumberOfBytesRead,
                Path = data.Path,
                VolumeId = data.VolumeId
            };
        }

        /// <summary>
        /// Ensures that the data protobuffer that is used to communicate with the python process is 
        /// converted to a data contract that can be consummed by the .Net languages.
        /// </summary>
        /// <param name="proto">The protobuffer to be converted.</param>
        /// <returns>A data contract that can be consummed by the .Net languages.</returns>
        internal static QueueItemData ToQueueItemData(QueueItemProto proto)
        {
            return new QueueItemData
            {
                NodeId = proto.NodeId,
                Operation = proto.Operation,
                Path = proto.Path,
                VolumeId = proto.VolumeId
            };
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        internal static QueueItemProto ToQueueItemProto(QueueItemData data)
        {
            return new QueueItemProto
            {
                NodeId = data.NodeId,
                Operation = data.Operation,
                Path = data.Path,
                VolumeId = data.VolumeId
            };
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="proto"></param>
        /// <returns></returns>
        internal static ShareData ToShareData(ShareProto proto)
        {
            return new ShareData
            {
                AccessLevel = proto.AccessLevel,
                FreeBytes = proto.FreeBytes,
                IsAccepted = proto.IsAccepted,
                Name = proto.Name,
                OtherUserName = proto.OtherUserName,
                OtherVisisbleName = proto.OtherVisisbleName,
                Path = proto.Path,
                VolumeId = proto.VolumeId,
                NodeId = proto.NodeId
           };
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        internal static ShareProto ToShareProto(ShareData data)
        {
            return new ShareProto
            {
                AccessLevel = data.AccessLevel,
                FreeBytes = data.FreeBytes,
                IsAccepted = data.IsAccepted,
                Name = data.Name,
                NodeId = data.NodeId,
                OtherUserName = data.OtherUserName,
                OtherVisisbleName = data.OtherVisisbleName,
                Path = data.Path,
                VolumeId = data.VolumeId
            };
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="proto"></param>
        /// <returns></returns>
        internal static ShareResponseData ToShareResponseData(ShareResponseProto proto)
        {
            // TODO: Correctly define the share response data.
            return new ShareResponseData();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        internal static ShareResponseProto ToShareResponseProto(ShareResponseData data)
        {
            // TODO: Correctly define the share response proto
            return new ShareResponseProto();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="proto"></param>
        /// <returns></returns>
        internal static StateData ToStateData(StateProto proto)
        {
            return new StateData
            {
                Description = proto.Description,
                IsConnected = proto.IsConnected,
                IsError = proto.IsError,
                IsOnline = proto.IsOnline,
                Name = proto.Name
            };
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        internal static StateProto ToStateProto(StateData data)
        {
            return new StateProto
            {
                Description = data.Description,
                IsConnected = data.IsConnected,
                IsError = data.IsError,
                IsOnline = data.IsOnline,
                Name = data.Name
            };
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="proto"></param>
        /// <returns></returns>
        internal static ThrottlingData ToThrottlingData(ThrottlingProto proto)
        {
            return new ThrottlingData
            {
                Download = proto.Download, 
                Upload = proto.Upload
            };
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        internal static ThrottlingProto ToThrottlingProto(ThrottlingData data)
        {
            return new ThrottlingProto
            {
                Download = data.Download, 
                Upload = data.Upload
            };
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="proto"></param>
        /// <returns></returns>
        internal static UdfData ToUdfData(UdfProto proto)
        {
            return new UdfData
            {
                IsSubscribed = proto.IsSubscribed,
                NodeId = proto.NodeId,
                Path = proto.Path,
                SuggestedPath = proto.SuggestedPath,
                VolumeId = proto.VolumeId
            };
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        internal static UdfProto ToUdfProto(UdfData data)
        {
            return new UdfProto
            {
                IsSubscribed = data.IsSubscribed,
                NodeId = data.NodeId,
                Path = data.Path,
                SuggestedPath = data.SuggestedPath,
                VolumeId = data.VolumeId
            };
        }

        /// <summary>
        /// Ensures that the protobuffer that is sued to communicate with the python process can ve converted
        /// to the data contract that can be consummed by the .Net languages.
        /// </summary>
        /// <param name="proto">The protobuffer to be converted.</param>
        /// <returns>A data contract that can be consummed by the .Net lanagues.</returns>
        internal static UploadData ToUploadData(UploadProto proto)
        {
            return new UploadData
            {
                NodeId = proto.NodeId,
                NumberOfBytesWritten = proto.NumberOfBytesWritten,
                Path = proto.Path,
                VolumeId = proto.VolumeId
            };
        }

        /// <summary>
        /// Ensures that the data contract that is consummed by the .Net languages is converted to 
        /// a protobuffer that can be used to communicate with the python process.
        /// </summary>
        /// <param name="data">The data contract to be converted.</param>
        /// <returns>A protobuffer that can be used to communicate with the python process.</returns>
        internal static UploadProto ToUploadProto(UploadData data)
        {
            return new UploadProto
            {
                NodeId = data.NodeId,
                NumberOfBytesWritten = data.NumberOfBytesWritten,
                Path = data.Path,
                VolumeId = data.VolumeId
            };
        }
    }
}
