﻿/**
 * Copyright 2009 Canonical Ltd.
 * 
 * This file is part of UbuntuOne on Windows.
 * 
 * UbuntuOne on Windows is free software: you can redistribute it and/or modify		
 * it under the terms of the GNU Lesser General Public License version 		
 * as published by the Free Software Foundation.		
 *		
 * Ubuntu One on Windows is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	
 * GNU Lesser General Public License for more details.	
 *
 * You should have received a copy of the GNU Lesser General Public License	
 * along with UbuntuOne for Windows.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Authors: Manuel de la Pena <manuel.delapena@canonical.com>
 */
using Canonical.UbuntuOne.Common;
using ProtoBuf;

namespace Canonical.UbuntuOne.ProcessDispatcher
{
    /// <summary>
    /// This class represents the proto contract that is used to communicate between the python process and 
    /// the .Net process using named pipes. The .Net applications should not have knowledge of this since it is 
    /// an implementation detail. .Net clients should use WCF which represents the more stable API.
    /// </summary>
    [ProtoContract]
    internal class ShareProto : NodeProto
    {
        /// <summary>
        /// Gets and sets the name of the share.
        /// </summary>
        [ProtoMember(4)]
        public string Name { get; set; }

        /// <summary>
        /// Gets and sets the username of the user that shared the name.
        /// </summary>
        [ProtoMember(5)]
        public string OtherUserName { get; set; }

        /// <summary>
        /// The visisble name of the user. As a user you have a username: mande and a name: Manuel de la Pena
        /// this property returns the name: Manuel de la Pena.
        /// </summary>
        [ProtoMember(6)]
        public string OtherVisisbleName { get; set; }

        /// <summary>
        /// Gets and sets if the share was accepted.
        /// </summary>
        [ProtoMember(7)]
        public bool IsAccepted { get; set; }

        /// <summary>
        /// Gets and sets the access level that the user has in the share.
        /// </summary>
        [ProtoMember(8)]
        public AccessLevel AccessLevel { get; set; }

        /// <summary>
        /// Gets and sets the amount of bytes that you can add to the share.
        /// </summary>
        [ProtoMember(9)]
        public int FreeBytes { get; set; }
    }
}
